pub enum DesktopError {
ChannelSend,
WindowClosed,
}Expand description
Errors that can occur when using the Desktop driver.
Variants
ChannelSend
Sending to the render thread failed because it has already hung up.
WindowClosed
Window has been closed.